#' @keywords internal
"_PACKAGE"

utils::globalVariables(
  c(
    "simid",
    "simtime",
    "simevent",
    "time",
    "varname",
    "value",
    "id",
    "grp"
  )
)
